@@ -51,7 +51,7 @@ def repackUMD(isofile, isopatch, workfolder, patchfile=""):
         return
     files = common.getFiles(workfolder)
     for file in common.showProgress(files):
-        common.execute(umdreplace + " \"{imagename}\" \"{filename}\" \"{newfile}\"".format(imagename=isopatch, filename=file, newfile=workfolder + file), False)
+        common.execute(umdreplace + " \"{imagename}\" \"/{filename}\" \"{newfile}\"".format(imagename=isopatch, filename=file, newfile=workfolder + file), False)
     common.logMessage("Done!")
     # Create xdelta patch
     if patchfile != "":
@@ -410,7 +410,7 @@ def writeGIM(file, gim, infile, backwardspal=False):
             f.seek(gim.imgoff)
             for i in range(gim.height):
                 for j in range(gim.width):
-                   writeColor(f, 0x03, pixels[j, gim.height - 1 - i], backwardspal)
+                   writeColor(f, 0x03, pixels[j, gim.height - 1 - i])
 
 
 def writeGIMPixel(f, image, color, backwards=False):
